summaryrefslogtreecommitdiffstats
path: root/kchart/kchartParameter3dConfigPage.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kchart/kchartParameter3dConfigPage.cc')
-rw-r--r--kchart/kchartParameter3dConfigPage.cc58
1 files changed, 29 insertions, 29 deletions
diff --git a/kchart/kchartParameter3dConfigPage.cc b/kchart/kchartParameter3dConfigPage.cc
index 07468544..fa3a5862 100644
--- a/kchart/kchartParameter3dConfigPage.cc
+++ b/kchart/kchartParameter3dConfigPage.cc
@@ -23,11 +23,11 @@
#include <kapplication.h>
#include <kdialog.h>
#include <klocale.h>
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qcheckbox.h>
-#include <qbuttongroup.h>
-#include <qwhatsthis.h>
+#include <tqlayout.h>
+#include <tqlabel.h>
+#include <tqcheckbox.h>
+#include <tqbuttongroup.h>
+#include <tqwhatsthis.h>
#include "kchart_params.h"
@@ -35,54 +35,54 @@ namespace KChart
{
KChartParameter3dConfigPage::KChartParameter3dConfigPage( KChartParams* params,
- QWidget* parent ) :
- QWidget( parent ),m_params( params )
+ TQWidget* tqparent ) :
+ TQWidget( tqparent ),m_params( params )
{
- QGridLayout* layout = new QGridLayout(this, 2, 2,KDialog::marginHint(),KDialog::spacingHint());
+ TQGridLayout* tqlayout = new TQGridLayout(this, 2, 2,KDialog::marginHint(),KDialog::spacingHint());
- QButtonGroup* gb = new QButtonGroup( 0, Qt::Vertical,
+ TQButtonGroup* gb = new TQButtonGroup( 0, Qt::Vertical,
i18n("3D Parameters"), this );
- gb->layout()->setSpacing(KDialog::spacingHint());
- gb->layout()->setMargin(KDialog::marginHint());
+ gb->tqlayout()->setSpacing(KDialog::spacingHint());
+ gb->tqlayout()->setMargin(KDialog::marginHint());
- // The grid layout inside the buttongroup.
- QGridLayout *grid1 = new QGridLayout(gb->layout(), 5, 3);
- layout->addWidget(gb,0,0);
+ // The grid tqlayout inside the buttongroup.
+ TQGridLayout *grid1 = new TQGridLayout(gb->tqlayout(), 5, 3);
+ tqlayout->addWidget(gb,0,0);
// The main on/off checkbox.
- bar3d=new QCheckBox(i18n("3D bar"),gb);
- QWhatsThis::add(bar3d, i18n("If checked, this will enable 3D mode for viewing the bars. You can then add a shadow and set the angle and depth for 3D."));
+ bar3d=new TQCheckBox(i18n("3D bar"),gb);
+ TQWhatsThis::add(bar3d, i18n("If checked, this will enable 3D mode for viewing the bars. You can then add a shadow and set the angle and depth for 3D."));
grid1->addWidget(bar3d,0,0);
- connect(bar3d, SIGNAL(toggled ( bool )),
- this, SLOT(slotChange3DParameter(bool)));
+ connect(bar3d, TQT_SIGNAL(toggled ( bool )),
+ this, TQT_SLOT(slotChange3DParameter(bool)));
// Checkbox for shadows
- drawShadowColor=new QCheckBox(i18n("Draw dark shadow"),gb);
- QWhatsThis::add(drawShadowColor, i18n("If checked, this will add a dark shadow on the 3D bars."));
+ drawShadowColor=new TQCheckBox(i18n("Draw dark shadow"),gb);
+ TQWhatsThis::add(drawShadowColor, i18n("If checked, this will add a dark shadow on the 3D bars."));
grid1->addWidget(drawShadowColor,1,0);
- QLabel *tmpLabel = new QLabel( i18n( "Angle:" ), gb );
- tmpLabel->resize( tmpLabel->sizeHint() );
+ TQLabel *tmpLabel = new TQLabel( i18n( "Angle:" ), gb );
+ tmpLabel->resize( tmpLabel->tqsizeHint() );
grid1->addWidget(tmpLabel,2,0);
angle3d=new KIntNumInput(0, gb, 10);
- QWhatsThis::add(angle3d, i18n("You can set here the angle for the 3D effect from 0 to 90. 90 will give you flat bars without any 3D effect.\nDefault is 45."));
+ TQWhatsThis::add(angle3d, i18n("You can set here the angle for the 3D effect from 0 to 90. 90 will give you flat bars without any 3D effect.\nDefault is 45."));
grid1->addWidget(angle3d,2,1);
angle3d->setRange(0, 90, 1);
- tmpLabel = new QLabel( i18n( "Depth:" ), gb );
- tmpLabel->resize( tmpLabel->sizeHint() );
+ tmpLabel = new TQLabel( i18n( "Depth:" ), gb );
+ tmpLabel->resize( tmpLabel->tqsizeHint() );
grid1->addWidget(tmpLabel,3,0);
depth=new KDoubleNumInput(0, gb);
- QWhatsThis::add(depth, i18n("You can set here the depth of the 3D effect from 0 to 2. 0 will give you no depth at all.\nDefault is 1."));
- depth->resize(100,depth->sizeHint().height());
+ TQWhatsThis::add(depth, i18n("You can set here the depth of the 3D effect from 0 to 2. 0 will give you no depth at all.\nDefault is 1."));
+ depth->resize(100,depth->tqsizeHint().height());
grid1->addWidget(depth,3,1);
depth->setRange(0, 2.0, 0.1);
- gb->setAlignment(Qt::AlignLeft);
+ gb->tqsetAlignment(TQt::AlignLeft);
grid1->addColSpacing(0,depth->width());
grid1->addColSpacing(0,angle3d->width());
grid1->setColStretch(2,1);
@@ -90,7 +90,7 @@ KChartParameter3dConfigPage::KChartParameter3dConfigPage( KChartParams* params,
//it's not good but I don't know how
//to reduce space
- //layout->addColSpacing(1,300);
+ //tqlayout->addColSpacing(1,300);
}